@@ -72,6 +72,9 @@ def concat_pandas_columns(data, name='concat_column', sep='|', return_data=False
 	def concat_row(x):
 		return sep.join([str(value) for value in x.values if value is not None])
 
+	data = data.copy()
+	if name in data.columns:
+		data.drop(columns=name, inplace=True)
 	data[name] = data.apply(concat_row, axis=1)
 
 	if return_data:
